@@ -121,6 +121,8 @@ def basic_flask_app(
         "OIDC_DISCOVERY_URL": f"http://{int_testing_env_vars['KC_HOSTNAME']}:{int_testing_env_vars['KC_PORT']}/"
         f"realms/{int_testing_env_vars['KC_REALM']}/.well-known/openid-configuration",
         "SQLALCHEMY_DATABASE_URI": db_uri,
+        "OPENAPI_GEN_SERVER_URL": f"http://{int_testing_env_vars['LOCAL_HOSTNAME']}:"
+        f"{int_testing_env_vars['OPENAPI_GEN_SERVER_PORT']}",
         "DB_AUTO_UPGRADE": True,
         "DB_MIGRATION_DIR": migration_directory,
     }
@@ -156,7 +158,6 @@ def primed_test_client(
     """Flask app configured for testing with the database pre-populated with test data."""
 
     for i in range(len(pets_test_data_set)):
-
         with app_test_client.post(pets_url, headers=access_token_headers, json=pets_test_data_set[i]) as ret:
             assert ret.status_code == 201
 
@@ -164,6 +165,6 @@ def primed_test_client(
             pets_test_data_set[i]["id"] = ret.json["id"]  # type: ignore
 
             # Verify pets data integrity
-            assert helpers.is_sub_dict(pets_test_data_set[i], ret.json)
+            assert helpers.is_sub_dict(pets_test_data_set[i], ret.json)  # type: ignore
 
     return app_test_client
